@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.21 2005/01/20 15:40:40 chpe Exp $
+ *  $Id: sgml-validator.c,v 1.22 2005/01/28 22:29:27 chpe Exp $
  */
 
 #include "config.h"
@@ -133,7 +133,7 @@ sgml_validator_class_init (SgmlValidatorClass *klass)
 static void
 sgml_validator_init (SgmlValidator *validator)
 {
-	LOG ("SgmlValidator initializing %p", validator)
+	LOG ("SgmlValidator initializing %p", validator);
 
 	validator->priv = SGML_VALIDATOR_GET_PRIVATE (validator);
 }
@@ -143,7 +143,7 @@ sgml_validator_finalize (GObject *object)
 {
 	SgmlValidatorPrivate *priv = SGML_VALIDATOR_GET_PRIVATE (SGML_VALIDATOR (object));
 
-	LOG ("SgmlValidator finalizing %p", object)
+	LOG ("SgmlValidator finalizing %p", object);
 
 	g_object_unref (priv->error_viewer);
 
