@@ -23,7 +23,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.43.2.1 2005/03/21 20:38:42 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.43.2.2 2005/04/14 17:23:06 chpe Exp $
  */
 
 #include "config.h"
@@ -1190,7 +1190,7 @@ media_drag_data_get_cb (GtkWidget *widget,
 	gtk_selection_data_set (selection_data,
 			selection_data->target,
 			8,
-			address,
+			(const guchar *) address,
 			strlen(address));
 }
 
@@ -1433,7 +1433,7 @@ links_drag_data_get_cb (GtkWidget *widget,
 	gtk_selection_data_set (selection_data,
 			        selection_data->target,
 			        8,
-			        address,
+			        (const guchar *)address,
 			        strlen(address));
 
 	g_free (address);
